import { IMainMenu } from '@jupyterlab/mainmenu';
import { PathExt } from "@jupyterlab/coreutils";
import { MenuSvg, folderIcon, pythonIcon, terminalIcon, textEditorIcon, } from '@jupyterlab/ui-components';
// import { URLExt } from "@jupyterlab/coreutils";
//
// import { ServerConnection } from "@jupyterlab/services";
import { ICommandPalette } from '@jupyterlab/apputils';
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.open = "ipynb:open";
})(CommandIDs || (CommandIDs = {}));
/**
 * Convert the list of snippets a tree.
 * @param snippets The list of snippets.
 */
function toTree(snippets) {
    const tree = new Map();
    snippets.forEach(snippet => {
        let node = tree;
        snippet.forEach(part => {
            if (!node.has(part)) {
                node.set(part, new Map());
            }
            node = node.get(part);
        });
    });
    return tree;
}
/**
 * Create a menu from a tree of snippets.
 * @param commands The command registry.
 * @param tree The tree of snippets.
 * @param path The current path in the tree.
 */
function createMenu(commands, tree, path = []) {
    const menu = new MenuSvg({ commands });
    for (const [name, map] of tree.entries()) {
        const fullpath = path.concat(name);
        if (map.size === 0) {
            menu.addItem({
                command: CommandIDs.open,
                args: { label: name, path: fullpath }
            });
        }
        else {
            const submenu = createMenu(commands, map, path.concat(name));
            submenu.title.label = name;
            submenu.title.icon = folderIcon;
            menu.addItem({ type: 'submenu', submenu });
        }
    }
    return menu;
}
const extension = {
    id: 'main-menu',
    autoStart: true,
    requires: [ICommandPalette, IMainMenu],
    activate: async (app, palette, mainMenu) => {
        const { commands } = app;
        console.log('JupyterLab extension jupyterlab_menu_project is activated!');
        // const Teach_Case = [
        //   {
        //     name: '聚类算法交互.ipynb',
        //   }
        // ];
        // Teach_Case.forEach(item => appendNewCommand(item));
        // function appendNewCommand(item: any) {
        // let command = `Teach_Case-${item.name}:show`;
        // const settings = ServerConnection.makeSettings();
        // const prefix = URLExt.join(
        //     settings.baseUrl,
        //     "multiple_cases"
        // );
        commands.addCommand(CommandIDs.open, {
            label: args => args['label'],
            icon: args => {
                const ext = PathExt.extname(args['label']);
                if (ext === '.py') {
                    return pythonIcon;
                }
                if (ext === '.sh') {
                    return terminalIcon;
                }
                return textEditorIcon;
            },
            execute: async (args) => {
                commands.execute('docmanager:open', {
                    path: ".cases/" + args['label']
                });
            }
        });
        // }
        // Create a menu
        // let tutorialMenu: Menu = new Menu({ commands });
        // tutorialMenu.title.label = 'Teach_Case';
        // Teach_Case.forEach(item => tutorialMenu.addItem({command: `Teach_Case-${item.name}:show`}));
        // mainMenu.addMenu(tutorialMenu, { rank: 80 });
        const snippet_list = [
            [
                "teach_case",
                [
                    ["分类", "逻辑回归.ipynb"],
                    ["分类", "SVM.ipynb"],
                    ["分类", "朴素贝叶斯.ipynb"],
                    ["分类", "DecisionTree.ipynb"],
                    ["分类", "RandomForest.ipynb"],
                    ["分类", "GBDT.ipynb"],
                    ["分类", "XGBoost.ipynb"],
                    ["分类", "LightGBM.ipynb"],
                    ["分类", "CatBoost.ipynb"],
                    ["分类", "gcForest.ipynb"],
                    ["分类", "SPLBoost.ipynb"],
                    ["分类", ".ipynb"],
                    ["分类", ".ipynb"],
                    ["聚类", "KMeans聚类.ipynb"],
                    ["聚类", "均值漂移聚类.ipynb"],
                    ["聚类", "谱聚类.ipynb"],
                    ["聚类", "AP聚类.ipynb"],
                    ["聚类", "DBSCAN聚类.ipynb"],
                    ["聚类", "Birch聚类.ipynb"],
                    ["聚类", "Agglomerative聚类.ipynb"],
                    ["聚类", "混合高斯聚类.ipynb"],
                    ["聚类", "幂迭代聚类.ipynb"],
                    ["聚类", "Weber-Fechner聚类.ipynb"],
                    ["优化", "正则化模型.ipynb"],
                    ["优化", "梯度下降算法.ipynb"],
                    ["优化", "阈值迭代算法.ipynb"],
                    ["优化", "ADMM算法.ipynb"],
                    ["优化", "阈值迭代算法应用.ipynb"],
                    ["优化", "分布式阈值迭代算法.ipynb"],
                    ["优化", "分布式ADMM算法.ipynb"],
                    ["回归", "SVM.ipynb"],
                    ["回归", "DecisionTree.ipynb"],
                    ["回归", "RandomForest.ipynb"],
                    ["回归", "GBDT.ipynb"],
                    ["回归", "XGBoost.ipynb"],
                    ["回归", "LightGBM.ipynb"],
                    ["回归", "CatBoost.ipynb"],
                    ["回归", "线性回归方法.ipynb"],
                    ["回归", "广义线性回归.ipynb"],
                    ["回归", "阈值迭代算法.ipynb"],
                    ["回归", "ADMM算法.ipynb"],
                    ["回归", "核岭回归.ipynb"],
                    ["回归", ".ipynb"],
                    ["回归", ".ipynb"],
                    ["回归", ".ipynb"],
                    ["时序", "LSTM.ipynb"],
                    ["时序", "ARIMA.ipynb"],
                ]
            ]
        ];
        for (var i = 0; i < snippet_list.length; i++) {
            var name = String(snippet_list[i][0]);
            var list = snippet_list[i][1];
            let tutorialMenu = createMenu(commands, toTree(list), [name]);
            tutorialMenu.title.label = name;
            mainMenu.addMenu(tutorialMenu);
        }
    }
};
export default extension;
